package cz.muni.fi.pv239.firstapp.myapplication2.app.database;

import android.content.ContentProvider;
import android.content.ContentUris;
import android.content.ContentValues;
import android.content.Context;
import android.content.UriMatcher;
import android.content.pm.ProviderInfo;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteQueryBuilder;
import android.net.Uri;
import android.provider.BaseColumns;
import android.text.TextUtils;
import android.util.Log;


public class Provider extends ContentProvider
{

    private static final int STUDENTS = 1;
    private static final int STUDENTS_ITEM = 2;

    private UriMatcher mUriMatcher;
    private DatabaseHelper mDatabaseHelper;

    @Override
    public boolean onCreate()
    {
        mDatabaseHelper = DatabaseHelper.getInstance(getContext());
        return true;
    }

    @Override
    public void attachInfo(Context context, ProviderInfo info)
    {
        super.attachInfo(context, info);
        mUriMatcher = new UriMatcher(UriMatcher.NO_MATCH);
        mUriMatcher.addURI(info.authority, Students.PATH_STUDENTS, STUDENTS);
        mUriMatcher.addURI(info.authority, Students.PATH_STUDENTS + "/*", STUDENTS_ITEM);
    }

    @Override
    public String getType(Uri uri)
    {
        switch (mUriMatcher.match(uri))
        {
            case STUDENTS:
                return Students.CONTENT_TYPE;
            case STUDENTS_ITEM:
                return Students.CONTENT_ITEM_TYPE;
            default:
                return null;
        }
    }

    @Override
    public Cursor query(Uri uri, String[] projection, String selection, String[] selectionArgs, String sortOrder)
    {
//        Toast.makeText(getContext(),"query",Toast.LENGTH_SHORT).show();
        final int type = mUriMatcher.match(uri);
        final SQLiteQueryBuilder qb = new SQLiteQueryBuilder();

        String defaultOrderBy = null;
        String groupBy = null;
        Cursor c = null;
        switch (type)
        {
            case STUDENTS_ITEM:
                qb.appendWhere(Students._ID + " = " + uri.getLastPathSegment());
            case STUDENTS:
                if(sortOrder==null){
                    defaultOrderBy= Students.DEFAULT_ORDER_BY;
                } else {
                    defaultOrderBy=sortOrder;
                }

                qb.setTables(DatabaseHelper.TABLE_STUDENTS);
                break;
            default:
                throw new IllegalArgumentException("Unsupported uri: " + uri);
        }

        if (TextUtils.isEmpty(sortOrder))
        {
            sortOrder = defaultOrderBy;
        }

        c = qb.query(mDatabaseHelper.getWritableDatabase(), projection, selection, selectionArgs, groupBy, null, sortOrder);
        c.setNotificationUri(getContext().getContentResolver(), uri);
        return c;
    }

    @Override
    public Uri insert(Uri uri, ContentValues values)
    {
        // Validate the requested uri
        switch (mUriMatcher.match(uri))
        {
            case STUDENTS:
            {
                SQLiteDatabase db = DatabaseHelper.getInstance(getContext()).getWritableDatabase();
                long rowId = db.insert(DatabaseHelper.TABLE_STUDENTS, null, values);

                Log.i("PRovider","rowID:"+rowId);

                Uri noteUri = ContentUris.withAppendedId(Students.contentUri(), rowId);
                getContext().getContentResolver().notifyChange(noteUri, null);
                return noteUri;
            }
        }

        throw new IllegalArgumentException("Unknown URI " + uri);
    }

    @Override
    public int delete(Uri uri, String selection, String[] selectionArgs)
    {
        return 0;
    }

    @Override
    public int update(Uri uri, ContentValues values, String selection, String[] selectionArgs)
    {
        return 0;
    }


    /**
     * default provider authority
     */
    public static final String AUTHORITY = "cz.muni.fi.pv239.firstapp.myapplication2.app";
    public static final Uri AUTHORITY_URI = Uri.parse("content://" + AUTHORITY);

    /**
     * Database columns for students.
     */
    interface StudentColumns
    {
        String UCO = "uco";
        String NAME = "name";
        String DESCRIPTION = "description";
        String IMAGE = "image";
    }

    public static class Students implements BaseColumns, StudentColumns
    {

        /**
         * uri path for the list of books
         */
        static final String PATH_STUDENTS = "students";

        /**
         * mime/content type for list of books
         */
        public static final String CONTENT_TYPE = "vnd.android.cursor.dir/vnd.cz.muni.fi.pv239.firstapp.myapplication2.app.student";

        /**
         * mime/content type for book in the list of books
         */
        public static final String CONTENT_ITEM_TYPE = "vnd.android.cursor.item/vnd.cz.muni.fi.pv239.firstapp.myapplication2.app.student";

        /**
         * ordered by {@link BaseColumns#_ID}
         */
        public static final String DEFAULT_ORDER_BY = NAME;

        private Students()
        {
        }

        /**
         * Gets uri for list of students.
         */
        public static Uri contentUri()
        {
            final Uri.Builder b = AUTHORITY_URI.buildUpon();
            b.appendPath(PATH_STUDENTS);
            return b.build();
        }

        /**
         * Gets uri for one book in the list of books by given {@code id}.
         */
        public static Uri contentItemUri(long id)
        {
            final Uri.Builder b = AUTHORITY_URI.buildUpon();
            b.appendPath(PATH_STUDENTS);
            b.appendPath(String.valueOf(id));
            return b.build();
        }
    }
}