package cz.muni.fi.pv239.firstapp.myapplication2.app.fragments;


import android.app.Activity;
import android.app.Notification;
import android.app.NotificationManager;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.res.Configuration;
import android.database.Cursor;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Bundle;
import android.support.v4.app.ListFragment;
import android.support.v4.app.LoaderManager;
import android.support.v4.app.NotificationCompat;
import android.support.v4.content.CursorLoader;
import android.util.Log;
import android.view.MenuItem;
import android.view.View;
import android.widget.ListView;
import android.widget.Toast;

import cz.muni.fi.pv239.firstapp.myapplication2.app.MyAdapter;
import cz.muni.fi.pv239.firstapp.myapplication2.app.R;
import cz.muni.fi.pv239.firstapp.myapplication2.app.RefreshService;
import cz.muni.fi.pv239.firstapp.myapplication2.app.database.Provider;

/**
 * Created by Wendy on 10.3.14.
 */
public class MyListFragment extends ListFragment implements LoaderManager.LoaderCallbacks<Cursor>
{
    OnListItemSelectedListener mListener;
    private   MyAdapter         mAdapter;
    protected BroadcastReceiver connectivityChangedReceiver;
    private   String            orderBy;

    public interface OnListItemSelectedListener
    {
        public void onListItemSelected(int position);
    }

    @Override
    public void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);

        setRetainInstance(true);
        setHasOptionsMenu(true);

        mAdapter = new MyAdapter(getActivity(), null, true);

//        View view = new View(getActivity());
//        view.setLayoutParams(new LinearLayout.LayoutParams(100,100));
//        view.setBackgroundColor(getResources().getColor(android.R.color.darker_gray));
//        getListView().setEmptyView(view);

        startMyService();

        ConnectivityManager mgr = (ConnectivityManager) getActivity().getSystemService(Context.CONNECTIVITY_SERVICE);
        NetworkInfo info = mgr.getActiveNetworkInfo();
        if (info == null || !info.isConnected())
        {

            connectivityChangedReceiver = new BroadcastReceiver()
            {
                @Override
                public void onReceive(Context context, Intent intent)
                {
                    boolean noConnectivity = intent.getBooleanExtra(ConnectivityManager.EXTRA_NO_CONNECTIVITY, false);
                    if (!noConnectivity)
                    {
                        startMyService();
                        try
                        {
                            getActivity().unregisterReceiver(connectivityChangedReceiver);
                        }
                        catch (Exception e)
                        {
                            Log.i("MyListFragment", "Handled exception during unregistering receiver: " + e.getMessage());
                        }
                        connectivityChangedReceiver = null;
                    }

                    NotificationCompat.Builder builder = new NotificationCompat.Builder(context).setContentText("Je čas na download!")
                            .setContentTitle(context.getText(R.string.app_name));

                    Notification notification = builder.build();
                    NotificationManager notificationManager = (NotificationManager) context.getSystemService(Context.NOTIFICATION_SERVICE);

                    notificationManager.notify(0, notification);
                }
            };
            getActivity().registerReceiver(connectivityChangedReceiver, new IntentFilter("android.net.conn.CONNECTIVITY_CHANGE"));
        }


    }

    public void startMyService()
    {
        final Intent i = new Intent(getActivity(), RefreshService.class);
        getActivity().startService(i);
    }

    @Override
    public android.support.v4.content.Loader<Cursor> onCreateLoader(int id, Bundle args)
    {
        Toast.makeText(getActivity(), "onCreateLoader", Toast.LENGTH_SHORT).show();
        return new CursorLoader(getActivity(),
                                Provider.Students.contentUri(),
                                new String[]{Provider.Students._ID,
                                        Provider.Students.NAME,
                                        Provider.Students.UCO,
                                        Provider.Students.IMAGE,
                                        Provider.Students.DESCRIPTION},
                                null, null, orderBy
        );
    }

    @Override
    public void onConfigurationChanged(Configuration newConfig)
    {

    }

    @Override
    public void onLoadFinished(android.support.v4.content.Loader<Cursor> loader, Cursor data)
    {
        if (isVisible())
        {
            if (getListAdapter() == null)
            {
                setListAdapter(mAdapter);
                setListShown(false);
            }
            mAdapter.swapCursor(data);

            Toast.makeText(getActivity(), "finished", Toast.LENGTH_SHORT).show();

            if (isResumed())
            {
                setListShown(true);
            }
            else
            {
                setListShownNoAnimation(true);
            }
        }
    }

    @Override
    public void onLoaderReset(android.support.v4.content.Loader<Cursor> loader)
    {
        mAdapter.swapCursor(null);
    }

    @Override
    public void onStart()
    {
        super.onStart();

        // When in two-pane layout, set the listview to highlight the selected list item
        // (We do this during onStart because at the point the listview is available.)
        if (getFragmentManager().findFragmentById(R.id.detail_fragment) != null)
        {
            getListView().setChoiceMode(ListView.CHOICE_MODE_SINGLE);
        }

        getActivity().getSupportLoaderManager().restartLoader(1, null, this);
    }

    @Override
    public void onAttach(Activity activity)
    {
        super.onAttach(activity);

        // This makes sure that the container activity has implemented
        // the callback interface. If not, it throws an exception.
        try
        {
            mListener = (OnListItemSelectedListener) activity;
        }
        catch (ClassCastException e)
        {
            throw new ClassCastException(activity.toString()
                                                 + " must implement OnListItemSelectedListener");
        }
    }

    @Override
    public void onListItemClick(ListView l, View v, int position, long id)
    {
        // Notify the parent activity of selected item
        mListener.onListItemSelected((int)mAdapter.getItemId(position));

        // Set the item as checked to be highlighted when in two-pane layout
        getListView().setItemChecked(position, true);

    }

    @Override
    public void onDetach()
    {
        super.onDetach();
        getActivity().getSupportLoaderManager().getLoader(1).stopLoading();
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item)
    {
        if (item.getItemId() == R.id.action_order_uco)
        {
            Toast.makeText(getActivity(), "onOptionsItemSelected UCO", Toast.LENGTH_SHORT).show();
            orderBy = "UCO";
            setListShown(false);
            getActivity().getSupportLoaderManager().restartLoader(1, null, this);
        }
        if (item.getItemId() == R.id.action_order_meno)
        {
            Toast.makeText(getActivity(), "onOptionsItemSelected NAME", Toast.LENGTH_SHORT).show();
            orderBy = "NAME";
            getActivity().getSupportLoaderManager().restartLoader(1, null, this);
        }


        return true;
    }
}
